@@ -288,6 +288,22 @@ struct DetectConditions<'a> {
 }
 
 const DETECTORS: &[DetectConditions] = &[
+    DetectConditions {
+        demux_name: "ace",
+        extensions: ".dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32LE(0xAC52))},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U16LE(2))},
+                      CheckItem{offs: 6, cond: &CC::Eq(Arg::U32LE(0xAC44))}]
+    },
+    DetectConditions {
+        demux_name: "ace",
+        extensions: ".dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32LE(8))},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U16LE(7))},
+                      CheckItem{offs: 6, cond: &CC::Eq(Arg::U32LE(0xAC5A))}]
+    },
     DetectConditions {
         demux_name: "acf",
         extensions: ".acf",
@@ -295,12 +311,25 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"FrameLen")},
                       CheckItem{offs: 8, cond: &CC::Eq(Arg::U32LE(0xFF4))}]
     },
+    DetectConditions {
+        demux_name: "ai_cda",
+        extensions: ".cda",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Or(&CC::Str(b"CDA2"), &CC::Str(b"CDAH"))}]
+    },
     DetectConditions {
         demux_name: "ark-an",
         extensions: ".an",
         regex:      "",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "ascon",
+        extensions: "",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"AN15")},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(64))}]
+    },
     DetectConditions {
         demux_name: "avf",
         extensions: ".avf",
@@ -328,6 +357,23 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32LE(0xAB12EF90))},
                       CheckItem{offs: 30, cond: &CC::Eq(Arg::U32LE(0xEE9901CF))} ]
     },
+    DetectConditions {
+        demux_name: "bal",
+        extensions: ".bal",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"INAE")},
+                      CheckItem{offs: 6, cond: &CC::Str(b"RLOC")}]
+    },
+    DetectConditions {
+        demux_name: "bd13",
+        extensions: "",
+        regex:      "",
+        conditions: &[CheckItem{offs:  0, cond: &CC::Eq(Arg::U16LE(8))},
+                      CheckItem{offs:  4, cond: &CC::Eq(Arg::U16LE(11))},
+                      CheckItem{offs:  8, cond: &CC::Eq(Arg::U32LE(16))},
+                      CheckItem{offs: 12, cond: &CC::Eq(Arg::U16LE(10))},
+                      CheckItem{offs: 14, cond: &CC::Eq(Arg::U16LE(1))}]
+    },
     DetectConditions {
         demux_name: "ca2",
         extensions: ".ca2",
@@ -365,6 +411,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "ACT.CRH,END.CRH,GO.CRH,INT.CRH",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "cyclemania",
+        extensions: ".hed",
+        regex:      "",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "cydonia",
         extensions: ".pac",
@@ -373,6 +425,20 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 4, cond: &CC::Eq(Arg::Byte(1))},
                       CheckItem{offs: 5, cond: &CC::Eq(Arg::U32LE(7))}]
     },
+    DetectConditions {
+        demux_name: "derf-aud",
+        extensions: ".adp",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"DERF")},
+                      CheckItem{offs: 4, cond: &CC::In(Arg::U32LE(1), Arg::U32LE(2))}]
+    },
+    DetectConditions {
+        demux_name: "derf-vid",
+        extensions: ".vds",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"DERF")},
+                      CheckItem{offs: 4, cond: &CC::Gt(Arg::U32LE(42))}]
+    },
     DetectConditions {
         demux_name: "dkanim",
         extensions: ".ani",
@@ -385,6 +451,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "drl",
+        extensions: ".drl",
+        regex:      "",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "duck-uqm",
         extensions: ".duk",
@@ -397,6 +469,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"ETV\x0A")}]
     },
+    DetectConditions {
+        demux_name: "fcmp",
+        extensions: ".cmp",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"FCMP")}],
+    },
     DetectConditions {
         demux_name: "fla",
         extensions: ".fla",
@@ -421,6 +499,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 4, cond: &CC::Or(&CC::Eq(Arg::U16LE(0x1234)), &CC::Eq(Arg::U16LE(0xAF43)))}]
     },
+    DetectConditions {
+        demux_name: "fst",
+        extensions: ".fst",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"2TSF")}],
+    },
     DetectConditions {
         demux_name: "guilty",
         extensions: "",
@@ -458,6 +542,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"JAM\0")}]
     },
+    DetectConditions {
+        demux_name: "jazz2",
+        extensions: ".j2v",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"CineFeed")}]
+    },
     DetectConditions {
         demux_name: "kdv-c",
         extensions: ".kdv",
@@ -496,6 +586,12 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(0x1C))},
                       CheckItem{offs: 0x1C, cond: &CC::Str(b"i42K")}]
     },
+    DetectConditions {
+        demux_name: "lair",
+        extensions: "",
+        regex:      "A\\d\\d\\d\\d\\d.DAT",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "lotr-av",
         extensions: ".av",
@@ -528,6 +624,20 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(64))},
                       CheckItem{offs: 16, cond: &CC::Or(&CC::Str(b"NXL1"), &CC::Str(b"NXL2"))}]
     },
+    DetectConditions {
+        demux_name: "origin-fli",
+        extensions: ".dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"FORM")},
+                      CheckItem{offs: 8, cond: &CC::Or(&CC::Str(b"INTR"), &CC::Str(b"ENDG"))},
+                      CheckItem{offs: 12, cond: &CC::Str(b"FLIC")}]
+    },
+    DetectConditions {
+        demux_name: "origin-ssm",
+        extensions: ".movie",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"MOVI")}]
+    },
     DetectConditions {
         demux_name: "paco",
         extensions: "",
@@ -549,6 +659,12 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"MOVE") },
                       CheckItem{offs: 8, cond: &CC::Str(b"MHED") }]
     },
+    DetectConditions {
+        demux_name: "psy-str",
+        extensions: ".str",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Or(&CC::Str(b"MRFI"), &CC::Eq(Arg::U32LE(0xF7F7F8F8))) }]
+    },
     DetectConditions {
         demux_name: "ptf",
         extensions: ".ptf",
@@ -576,6 +692,12 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"RATVID") },
                       CheckItem{offs: 6, cond: &CC::Eq(Arg::U16LE(1)) }]
     },
+    DetectConditions {
+        demux_name: "raven-anm",
+        extensions: ".anm",
+        regex:      "CINE\\d\\d.ANM",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "rbt",
         extensions: ".rbt",
@@ -597,6 +719,24 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"VID02") }]
     },
+    DetectConditions {
+        demux_name: "siff",
+        extensions: ".vb,.vbc,.fcp,.son",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"SIFF")},
+                      CheckItem{offs: 4, cond: &CC::Or(
+                                    &CC::Or(
+                                        &CC::Str(b"VBV1VBHD"),
+                                        &CC::Str(b"SOUNSHDR")),
+                                    &CC::Str(b"FCPKFCHD"))}],
+    },
+    DetectConditions {
+        demux_name: "soulhunt",
+        extensions: ".vid",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"DV")},
+                      CheckItem{offs: 2, cond: &CC::Eq(Arg::U16LE(0))}]
+    },
     DetectConditions {
         demux_name: "talisman",
         extensions: ".ani",
@@ -628,12 +768,44 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"VXDS") }],
     },
+    DetectConditions {
+        demux_name: "wingnuts",
+        extensions: ".dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32BE(0x1C)) },
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32BE(0x08000001)) },
+                      CheckItem{offs: 12, cond: &CC::Str(b"WinD") }],
+    },
     DetectConditions {
         demux_name: "xanth",
         extensions: "",
         regex:      "xanth_9\\d.pic",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "yo-mxv",
+        extensions: ".mxv",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"Archivo MXV.\x1A") }],
+    },
+    DetectConditions {
+        demux_name: "yumimi-ablk",
+        extensions: ".abk,.dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"ABLK") }],
+    },
+    DetectConditions {
+        demux_name: "yumimi-cut",
+        extensions: ".cut",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"ACUT") }],
+    },
+    DetectConditions {
+        demux_name: "zorton",
+        extensions: ".vip",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"VIP01") }],
+    },
 ];
 
 /// Tries to detect format by name and contents if possible.
