@@ -10,6 +10,7 @@ enum FlicType {
     FLC,
     FLH,
     MagicCarpet,
+    Origin,
     PTF
 }
 
@@ -367,6 +368,7 @@ struct FlicDecoder {
     frm_no:     u16,
     nframes:    u16,
     fli_end:    u64,
+    tot_size:   u64,
     speed:      u32,
     video:      VideoData,
     audio16:    Vec<i16>,
@@ -416,10 +418,43 @@ impl InputSource for FlicDecoder {
             std::mem::swap(&mut ret, &mut self.audio16);
             return Ok((1, Frame::AudioS16(ret)));
         }
+        let mut br = ByteReader::new(&mut self.fr);
+        if self.subtype == FlicType::Origin {
+            if br.tell() >= self.tot_size {
+                return Err(DecoderError::EOF);
+            }
+            if br.tell() >= self.fli_end {
+                if (br.tell() & 1) != 0 {
+                    br.read_skip(1)?;
+                }
+                let tag = br.read_tag()?;
+                // we can't handle FONT and VOCF chunks (yet?)
+                if &tag != b"FLIC" {
+                    return Err(DecoderError::EOF);
+                }
+                let size = br.read_u32be()?;
+                validate!(size > 0x8C);
+                self.fli_end = br.tell() + u64::from(size);
+                br.read_skip(12)?;
+
+                let tag         = br.read_u16le()?;
+                validate!(tag == 0xAF11);
+                let _nframes    = br.read_u16le()?;
+                let width       = br.read_u16le()? as usize;
+                let height      = br.read_u16le()? as usize;
+                validate!(width == self.video.width && height == self.video.height);
+                let depth       = br.read_u16le()?;
+                validate!(depth == 8);
+                let _flags      = br.read_u16le()?;
+                let _speed      = br.read_u32le()?;
+                                  br.read_skip(0x6C)?;
+                self.frm_no = 0;
+                self.nframes = 32000;
+            }
+        }
         if self.frm_no >= self.nframes {
             return Err(DecoderError::EOF);
         }
-        let mut br = ByteReader::new(&mut self.fr);
         while br.tell() < self.fli_end {
             let chunk_size = br.read_u32le()?;
             let chunk_type = br.read_u16le()?;
@@ -445,7 +480,7 @@ impl InputSource for FlicDecoder {
                 }
             }
             match self.subtype {
-                FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet => {
+                FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet | FlicType::Origin => {
                     validate!(chunk_type >= 0xF100);
                 },
                 FlicType::PTF => {},
@@ -511,14 +546,19 @@ impl InputSource for FlicDecoder {
                             validate!(subchunk_size & 1 == 0);
                         }
                         match self.subtype {
-                            FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet | FlicType::PTF => {
+                            FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet |
+                            FlicType::Origin | FlicType::PTF => {
                                 validate!(subchunk_type < 100);
                             },
                             FlicType::FLH => {
                                 validate!(subchunk_type < 100 || subchunk_type == 0x5555 || subchunk_type == 0x5344);
                             }
                         }
-                        validate!(subchunk_end <= chunk_end);
+                        if self.subtype != FlicType::Origin {
+                            validate!(subchunk_end <= chunk_end);
+                        } else {
+                            validate!(subchunk_end <= (chunk_end + 1) & !1);
+                        }
 
                         // FLH audio
                         if subchunk_type == 0x5344 {
@@ -546,7 +586,11 @@ impl InputSource for FlicDecoder {
                             validate!(br.tell() == subchunk_end);
                         } else {
                             validate!(br.tell() <= subchunk_end);
-                            br.seek(SeekFrom::Start(subchunk_end))?;
+                            if self.subtype != FlicType::Origin {
+                                br.seek(SeekFrom::Start(subchunk_end))?;
+                            } else {
+                                br.seek(SeekFrom::Start(subchunk_end.min(chunk_end)))?;
+                            }
                         }
                     }
 
@@ -597,6 +641,7 @@ pub fn open_fli(name: &str) -> DecoderResult<Box<dyn InputSource>> {
             nframes,
             speed: 66,
             fli_end: u64::from(std::u32::MAX),
+            tot_size: u64::from(std::u32::MAX),
             subtype: FlicType::MagicCarpet,
             audio16: Vec::new(),
             firstaud: false,
@@ -653,6 +698,7 @@ pub fn open_fli(name: &str) -> DecoderResult<Box<dyn InputSource>> {
         nframes,
         speed,
         fli_end: u64::from(if size > 128 { size } else { std::u32::MAX }),
+        tot_size: u64::from(if size > 128 { size } else { std::u32::MAX }),
         subtype: if tag == 0xAF11 { FlicType::FLI } else { FlicType::FLC },
         audio16: Vec::new(),
         firstaud: false,
@@ -715,6 +761,7 @@ pub fn open_flh(name: &str) -> DecoderResult<Box<dyn InputSource>> {
         nframes,
         speed: 1000 / speed,
         fli_end: u64::from(size),
+        tot_size: u64::from(size),
         subtype: FlicType::FLH,
         audio16: Vec::new(),
         firstaud: false,
@@ -732,6 +779,55 @@ pub fn open_flh(name: &str) -> DecoderResult<Box<dyn InputSource>> {
     }))
 }
 
+pub fn open_origin(name: &str) -> DecoderResult<Box<dyn InputSource>> {
+    let file = File::open(name).map_err(|_| DecoderError::InputNotFound(name.to_owned()))?;
+    let mut fr = FileReader::new_read(BufReader::new(file));
+    let mut br = ByteReader::new(&mut fr);
+
+    let tag         = br.read_tag()?;
+    validate!(&tag == b"FORM");
+    let tot_size    = br.read_u32le()?;
+    let tag         = br.read_tag()?;
+    validate!(&tag == b"INTR" || &tag == b"ENDG");
+    let tag         = br.read_tag()?;
+    validate!(&tag == b"FLIC");
+    br.read_skip(16)?;
+    let tag         = br.read_u16le()?;
+    validate!(tag == 0xAF11);
+    let _nframes    = br.read_u16le()?;
+    let width       = br.read_u16le()? as usize;
+    let height      = br.read_u16le()? as usize;
+    validate!(width > 0 && width <= 2048 && height > 0 && height <= 1536);
+    let depth       = br.read_u16le()?;
+    validate!(depth == 8);
+    let _flags      = br.read_u16le()?;
+    let speed       = br.read_u32le()?;
+                      br.seek(SeekFrom::Start(12))?;
+
+    Ok(Box::new(FlicDecoder {
+        fr,
+        frm_no: 0,
+        nframes: 0,
+        speed,
+        fli_end: 0,
+        tot_size: u64::from(tot_size),
+        subtype: FlicType::Origin,
+        audio16: Vec::new(),
+        firstaud: false,
+        aligned: false,
+        video: VideoData {
+            width, height, depth,
+            cur_w: width,
+            cur_h: height,
+            pal: [0; 768],
+            frame: vec![0; width * height],
+            frame16: Vec::new(),
+            unp_buf: Vec::new(),
+            vdata: Vec::new(),
+        },
+    }))
+}
+
 pub fn open_ptf(name: &str) -> DecoderResult<Box<dyn InputSource>> {
     let file = File::open(name).map_err(|_| DecoderError::InputNotFound(name.to_owned()))?;
     let mut fr = FileReader::new_read(BufReader::new(file));
@@ -760,6 +856,7 @@ pub fn open_ptf(name: &str) -> DecoderResult<Box<dyn InputSource>> {
         nframes,
         speed: 100,
         fli_end: u64::from(size),
+        tot_size: u64::from(size),
         subtype: FlicType::PTF,
         audio16: Vec::new(),
         firstaud: true,
